@@ -16,3 +16,8 @@ fi
 
 ./scripts/fault_tree_generator.py -b 200 -a 5
 scram --validate fault_tree.xml
+
+[[ "${TRAVIS_OS_NAME}" == "linux" ]] || exit 0
+
+LD_LIBRARY_PATH=${PWD}/install/lib/scram/test/:${LD_LIBRARY_PATH} \
+  scram --validate --allow-extern install/share/scram/input/model/system_extern_library.xml
