@@ -17,14 +17,10 @@
 
 #include "eventdialog.h"
 
-#include <limits>
-
 #include <QCompleter>
-#include <QDoubleValidator>
 #include <QListView>
 #include <QObject>
 #include <QPushButton>
-#include <QRegularExpressionValidator>
 #include <QShortcut>
 #include <QStatusBar>
 
@@ -39,6 +35,7 @@
 
 #include "guiassert.h"
 #include "overload.h"
+#include "validator.h"
 
 namespace scram {
 namespace gui {
@@ -49,21 +46,15 @@ QString EventDialog::yellowBackground(QStringLiteral("background : yellow;"));
 EventDialog::EventDialog(mef::Model *model, QWidget *parent)
     : QDialog(parent), m_model(model), m_errorBar(new QStatusBar(this))
 {
-    static QRegularExpressionValidator nameValidator(
-        QRegularExpression(QStringLiteral(R"([[:alpha:]]\w*(-\w+)*)")));
-    static QDoubleValidator nonNegativeValidator(
-        0, std::numeric_limits<double>::max(), 1000);
-    static QDoubleValidator probabilityValidator(0, 1, 1000);
-
     setupUi(this);
     gridLayout->addWidget(m_errorBar, gridLayout->rowCount(), 0,
                           gridLayout->rowCount(), gridLayout->columnCount());
 
-    nameLine->setValidator(&nameValidator);
-    constantValue->setValidator(&probabilityValidator);
-    exponentialRate->setValidator(&nonNegativeValidator);
-    addArgLine->setValidator(&nameValidator);
-    containerFaultTreeName->setValidator(&nameValidator);
+    nameLine->setValidator(Validator::name());
+    constantValue->setValidator(Validator::probability());
+    exponentialRate->setValidator(Validator::nonNegative());
+    addArgLine->setValidator(Validator::name());
+    containerFaultTreeName->setValidator(Validator::name());
 
     connect(typeBox, OVERLOAD(QComboBox, currentIndexChanged, int),
             [this](int index) {
@@ -122,12 +113,14 @@ EventDialog::EventDialog(mef::Model *model, QWidget *parent)
                 addArgLine->setStyleSheet(yellowBackground);
                 if (hasFormulaArg(name)) {
                     m_errorBar->showMessage(
+                        //: Duplicate arguments are not allowed in a formula.
                         tr("The argument '%1' is already in formula.")
                             .arg(name));
                     return;
                 }
                 if (name == nameLine->text()) {
                     m_errorBar->showMessage(
+                        //: Self-cycle is also called a loop in a graph.
                         tr("The argument '%1' would introduce a self-cycle.")
                             .arg(name));
                     return;
@@ -135,6 +128,7 @@ EventDialog::EventDialog(mef::Model *model, QWidget *parent)
                     auto it = m_model->gates().find(name.toStdString());
                     if (it != m_model->gates().end() && checkCycle(it->get())) {
                         m_errorBar->showMessage(
+                            //: Fault trees are acyclic graphs.
                             tr("The argument '%1' would introduce a cycle.")
                                 .arg(name));
                         return;
@@ -360,10 +354,11 @@ void EventDialog::validate()
         if (name != m_initName) {
             m_model->GetEvent(name.toStdString());
             m_errorBar->showMessage(
+                //: Duplicate event definition in the model.
                 tr("The event with name '%1' already exists.").arg(name));
             return;
         }
-    } catch (UndefinedElement &) {}
+    } catch (const mef::UndefinedElement &) {}
 
     if (!tabFormula->isHidden() && hasFormulaArg(name)) {
         m_errorBar->showMessage(
@@ -420,10 +415,12 @@ void EventDialog::validate()
             break;
         case mef::kVote:
             if (numArgs <= voteNumberBox->value()) {
+                int numReqArgs = voteNumberBox->value() + 1;
                 m_errorBar->showMessage(
-                    tr("%1 connective requires at-least %2 arguments.")
-                        .arg(connectiveBox->currentText(),
-                             QString::number(voteNumberBox->value() + 1)));
+                    //: The number of required arguments is always more than 2.
+                    tr("%1 connective requires at-least %n arguments.", "",
+                       numReqArgs)
+                        .arg(connectiveBox->currentText()));
                 return;
             }
             break;
@@ -441,6 +438,7 @@ void EventDialog::validate()
             = ext::find(m_model->fault_trees(), faultTreeName.toStdString())) {
             GUI_ASSERT((*it)->top_events().empty() == false, );
             m_errorBar->showMessage(
+                //: Fault tree redefinition.
                 tr("Fault tree '%1' is already defined with a top gate.")
                     .arg(faultTreeName));
             containerFaultTreeName->setStyleSheet(yellowBackground);
