@@ -28,13 +28,19 @@
 #include <QApplication>
 #include <QCoreApplication>
 #include <QIcon>
+#include <QLibraryInfo>
 #include <QMessageBox>
+#include <QSettings>
 #include <QString>
+#include <QTranslator>
 
+#include <boost/exception/diagnostic_information.hpp>
 #include <boost/program_options.hpp>
+#include <boost/range/algorithm.hpp>
 
 #include "mainwindow.h"
 
+#include "src/env.h"
 #include "src/error.h"
 #include "src/version.h"
 
@@ -63,7 +69,7 @@ int parseArguments(int argc, char *argv[], po::variables_map *vm) noexcept
              "Project configuration file");
     try {
         po::store(po::parse_command_line(argc, argv, desc), *vm);
-    } catch (std::exception &err) {
+    } catch (const std::exception &err) {
         std::cerr << "Option error: " << err.what() << "\n\n"
                   << usage << "\n\n"
                   << desc << "\n";
@@ -88,6 +94,16 @@ int parseArguments(int argc, char *argv[], po::variables_map *vm) noexcept
     return 0;
 }
 
+/// Produces critical notification dialog
+/// for errors that are not expected to crash the application.
+void notifyError(const QString &title, const QString &text,
+                 const QString &detail = {}) noexcept
+{
+    QMessageBox message(QMessageBox::Critical, title, text, QMessageBox::Ok);
+    message.setDetailedText(detail);
+    message.exec();
+}
+
 /// Guards the application from crashes on escaped internal exceptions.
 class GuardedApplication : public QApplication {
 public:
@@ -98,17 +114,20 @@ public:
         try {
             return QApplication::notify(receiver, event);
         } catch (const scram::Error &err) {
-            qCritical("%s", err.what());
-            QMessageBox::critical(nullptr, tr("Internal SCRAM Error"),
-                                  QString::fromUtf8(err.what()));
+            std::string message = boost::diagnostic_information(err);
+            qCritical("%s", message.c_str());
+            notifyError(QStringLiteral("Internal SCRAM Error"),
+                        QStringLiteral("Uncaught exception."),
+                        QString::fromStdString(message));
         } catch (const std::exception &err) {
             qCritical("%s", err.what());
-            QMessageBox::critical(nullptr, tr("Internal Exception Error"),
-                                  QString::fromUtf8(err.what()));
+            notifyError(QStringLiteral("Internal Exception Error"),
+                        QStringLiteral("Uncaught foreign exception."),
+                        QString::fromUtf8(err.what()));
         } catch (...) {
             qCritical("Unknown exception type.");
-            QMessageBox::critical(nullptr, tr("Internal Exception Error"),
-                                  tr("Unknown exception type."));
+            notifyError(QStringLiteral("Internal Exception Error"),
+                        QStringLiteral("Unknown exception type."));
         }
         return false;
     }
@@ -117,11 +136,12 @@ public:
 /// Produces the crash dialog with a given reasoning.
 /// The dialog allows access to other windows
 /// so that users may try saving the model before the crash.
-void crashDialog(const QString &text) noexcept
+void crashDialog(const QString &text, const QString &detail = {}) noexcept
 {
     QMessageBox message(QMessageBox::Critical,
-                        QObject::tr("Unrecoverable Internal Error"), text,
+                        QStringLiteral("Unrecoverable Internal Error"), text,
                         QMessageBox::Ok);
+    message.setDetailedText(detail);
     message.setWindowModality(Qt::WindowModal);
     message.exec();
 }
@@ -131,16 +151,19 @@ void crashHandler(int signum) noexcept
 {
     switch (signum) {
     case SIGSEGV:
-        crashDialog(QObject::tr("SIGSEGV: Invalid memory access."));
+        crashDialog(QStringLiteral("SIGSEGV: Invalid memory access."));
         break;
     case SIGFPE:
-        crashDialog(QObject::tr("SIGFPE: Erroneous arithmetic operation."));
+        crashDialog(QStringLiteral("SIGFPE: Erroneous arithmetic operation."));
         break;
     case SIGILL:
-        crashDialog(QObject::tr("SIGILL: Illegal instruction."));
+        crashDialog(QStringLiteral("SIGILL: Illegal instruction."));
         break;
     }
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
     std::signal(signum, SIG_DFL);
+#pragma GCC diagnostic pop
     std::raise(signum);
 }
 
@@ -152,29 +175,80 @@ static const std::terminate_handler gDefaultTerminateHandler
 void terminateHandler() noexcept
 {
     QString error;
+    QString detail;
     try {
         std::rethrow_exception(std::current_exception());
     } catch (const scram::Error &err) {
-        error = QObject::tr("SCRAM exception: %1")
-                    .arg(QString::fromUtf8(err.what()));
+        std::string message = boost::diagnostic_information(err);
+        qCritical("%s", message.c_str());
+        error = QStringLiteral("SCRAM exception.");
+        detail = QString::fromStdString(message);
     } catch (const std::exception &err) {
-        error = QObject::tr("Standard exception: %1")
-                    .arg(QString::fromUtf8(err.what()));
+        error = QStringLiteral("Standard exception.");
+        detail = QString::fromUtf8(err.what());
     } catch (...) {
-        error = QObject::tr("Exception of unknown type: no message available.");
+        error = QStringLiteral("Exception of unknown type without a message.");
     }
-    crashDialog(
-        QObject::tr("Exception no-throw contract violation:\n\n%1").arg(error));
+    crashDialog(QStringLiteral("No-throw contract violation:\n%1").arg(error),
+                detail);
     gDefaultTerminateHandler();
 }
 
 /// Installs crash handlers for system signals.
 void installCrashHandlers() noexcept
 {
-    std::signal(SIGSEGV, crashHandler);
-    std::signal(SIGFPE, crashHandler);
-    std::signal(SIGILL, crashHandler);
-    std::set_terminate(terminateHandler);
+    std::signal(SIGSEGV, &crashHandler);
+    std::signal(SIGFPE, &crashHandler);
+    std::signal(SIGILL, &crashHandler);
+    std::set_terminate(&terminateHandler);
+}
+
+/// @returns The UI language for the translator setup.
+QString getUiLanguage()
+{
+    /// @todo Discover available translations programmatically.
+    static const char *const availableLanguages[] = {"en", "ru_RU", "de_DE"};
+
+    QSettings preferences;
+    QString language = preferences.value(QStringLiteral("language")).toString();
+    if (!language.isEmpty())
+        return language;
+    QString system = QLocale::system().name();
+    auto it = boost::find(availableLanguages, system.toStdString());
+    if (it != std::end(availableLanguages))
+        return system;
+    return QStringLiteral("en");
+}
+
+/// Installs translators to the main application.
+///
+/// @param[in,out] app  The application to register translators.
+///
+/// @pre No application window has been created.
+void installTranslators(GuardedApplication *app)
+{
+    QString language = getUiLanguage();
+    if (language == QStringLiteral("en"))
+        return;  // The default language.
+
+    QString qtTsPath = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+    QString scramTsPath = QString::fromStdString(scram::Env::install_dir()
+                                                 + "/share/scram/translations");
+    std::pair<const char *, QString> domains[]
+        = {{"qtbase", qtTsPath}, {"qt", qtTsPath}, {"scramgui", scramTsPath}};
+
+    for (const auto &domain : domains) {
+        auto *translator = new QTranslator(app);
+        if (translator->load(QStringLiteral("%1_%2").arg(
+                                 QString::fromLatin1(domain.first), language),
+                             domain.second)) {
+            app->installTranslator(translator);
+        } else {
+            delete translator;
+            qCritical("Missing translations: %s_%s", domain.first,
+                      language.toStdString().data());
+        }
+    }
 }
 
 } // namespace
@@ -187,20 +261,21 @@ int main(int argc, char *argv[])
     // However, the most distributions are expected to be shared builds,
     // so the explicit load should not be used, but it is kept for debugging.
     /* Q_INIT_RESOURCE(res); */
-    GuardedApplication a(argc, argv);
+    GuardedApplication app(argc, argv);
 
     installCrashHandlers();
 
-    QCoreApplication::setOrganizationName(QString::fromLatin1("scram"));
-    QCoreApplication::setOrganizationDomain(
-        QString::fromLatin1("scram-pra.org"));
-    QCoreApplication::setApplicationName(QString::fromLatin1("scram"));
+    QCoreApplication::setOrganizationName(QStringLiteral("scram"));
+    QCoreApplication::setOrganizationDomain(QStringLiteral("scram-pra.org"));
+    QCoreApplication::setApplicationName(QStringLiteral("scram"));
     QCoreApplication::setApplicationVersion(
         QString::fromLatin1(scram::version::core()));
 
     if (QIcon::themeName().isEmpty())
         QIcon::setThemeName(QStringLiteral("tango"));
 
+    installTranslators(&app);
+
     scram::gui::MainWindow w;
     w.show();
 
@@ -220,7 +295,7 @@ int main(int argc, char *argv[])
             } else {
                 w.addInputFiles(inputFiles);
             }
-        } catch (boost::exception &) { assert(false); }
+        } catch (const boost::exception &) { assert(false); }
     }
-    return a.exec();
+    return app.exec();
 }
