@@ -18,10 +18,10 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+#include <array>
 #include <functional>
 #include <memory>
 #include <string>
-#include <unordered_map>
 #include <vector>
 
 #include <QAbstractItemView>
@@ -30,8 +30,9 @@
 #include <QDir>
 #include <QLineEdit>
 #include <QMainWindow>
-#include <QRegularExpressionValidator>
-#include <QTreeWidgetItem>
+#include <QSettings>
+#include <QTableView>
+#include <QTimer>
 #include <QUndoStack>
 
 #include "src/model.h"
@@ -57,9 +58,28 @@ public:
     explicit MainWindow(QWidget *parent = nullptr);
     ~MainWindow();
 
-    void setConfig(const std::string &configPath,
+    /// Loads a model and analysis configuration from a file.
+    ///
+    /// @param[in] configPath  The path to the configuration file.
+    /// @param[in] inputFiles  Additional input files for model initialization.
+    ///
+    /// @returns true if the initialization is successful.
+    ///
+    /// @post No side effects are left-over
+    ///       if the initialization is not successful.
+    bool setConfig(const std::string &configPath,
                    std::vector<std::string> inputFiles = {});
-    void addInputFiles(const std::vector<std::string> &inputFiles);
+
+    /// Adds a new set of model elements from input files.
+    ///
+    /// @param[in] inputFiles  Paths to input files.
+    ///
+    /// @returns true if the addition is successful.
+    ///
+    /// @post If the addition of any file is not successful,
+    ///       the model is left in its original state
+    ///       as if this function had not been called (i.e., transactional).
+    bool addInputFiles(const std::vector<std::string> &inputFiles);
 
 signals:
     void configChanged();
@@ -77,6 +97,12 @@ private slots:
      */
     void openFiles(QString directory = QDir::homePath());
 
+    /**
+     * @brief Implicitly saves the modified model
+     *        only if the destination is available.
+     */
+    void autoSaveModel();
+
     /**
      * @brief Saves the project to a file.
      *
@@ -100,8 +126,17 @@ private slots:
     void addElement();
 
 private:
-    void setupStatusBar(); ///< Setup widgets in the status bar.
-    void setupActions(); ///< Setup all the actions with connections.
+    static const int LAYOUT_VERSION = 0; ///< Layout compatibility version.
+
+    void setupStatusBar();   ///< Sets up widgets in the status bar.
+    void setupActions();     ///< Sets up all the actions with connections.
+    void setupConnections(); ///< Sets up all the remaining connections.
+    void loadPreferences();  ///< Loads the persistent application preferences.
+    void savePreferences();  ///< Writes the 'unsaved' application preferences.
+    void setupStartPage();   ///< Sets up a new start page.
+
+    /// @returns The model name to be used for a title (e.g., main window).
+    QString getModelNameForTitle();
 
     void setupZoomableView(ZoomableView *view); ///< Connect to actions.
 
@@ -143,6 +178,16 @@ private:
     template <class T>
     void removeEvent(T *event, mef::FaultTree *faultTree);
 
+    /// @tparam ContainerModel  The container model type.
+    /// @tparam Ts  The argument types for the container model.
+    ///
+    /// @param[in,out] parent  The parent to own the table view.
+    /// @param[in] modelArgs  The arguments for container model constructor.
+    ///
+    /// @returns Table view ready for inclusion to tabs.
+    template <class ContainerModel, typename... Ts>
+    QTableView *constructTableView(QWidget *parent, Ts&&... modelArgs);
+
     template <class ContainerModel>
     QAbstractItemView *constructElementTable(model::Model *guiModel,
                                              QWidget *parent);
@@ -168,6 +213,8 @@ private:
     void activateModelTree(const QModelIndex &index);
     /// Activates the fault tree view.
     void activateFaultTreeDiagram(mef::FaultTree *faultTree);
+    /// Activates the report tree elements.
+    void activateReportTree(const QModelIndex &index);
 
     /**
      * @brief Resets the report view.
@@ -175,7 +222,7 @@ private:
      * @param analysis  The analysis with results.
      *                  nullptr to clear the report widget.
      */
-    void resetReportWidget(std::unique_ptr<core::RiskAnalysis> analysis);
+    void resetReportTree(std::unique_ptr<core::RiskAnalysis> analysis);
 
     /**
      * Saves the model and sets the model file.
@@ -184,24 +231,47 @@ private:
      */
     void saveToFile(std::string destination);
 
+    /**
+     * Updates the recent file tracking.
+     *
+     * @param filePaths  The list to append to the recent file list.
+     *                   An empty list to clear the recent file list.
+     *
+     * @pre The list contains valid absolute input file paths.
+     *
+     * @note This does not store the result path list into persistent settings.
+     */
+    void updateRecentFiles(QStringList filePaths);
+
     /// Override to save the model before closing the application.
     void closeEvent(QCloseEvent *event) override;
 
+    /// Safely closes the tab with the given index in the widget.
+    ///
+    /// @param[in] index  The index of the tab to be removed.
+    ///
+    /// @post Show/hide order is respected for safe delete.
+    /// @post The closed tab is deleted.
+    void closeTab(int index);
+
+    /// Runs the analysis with the current model.
+    void runAnalysis();
+
     std::unique_ptr<Ui::MainWindow> ui;
     QAction *m_undoAction;
     QAction *m_redoAction;
     QUndoStack *m_undoStack;
+    QComboBox *m_zoomBox; ///< The main zoom chooser/displayer widget.
     QLineEdit *m_searchBar;
+    QTimer *m_autoSaveTimer;
+    QSettings m_preferences;
+    std::array<QAction *, 5> m_recentFileActions;
 
     std::vector<std::string> m_inputFiles;  ///< The project model files.
     core::Settings m_settings; ///< The analysis settings.
     std::shared_ptr<mef::Model> m_model; ///< The analysis model.
     std::unique_ptr<model::Model> m_guiModel;  ///< The GUI Model wrapper.
-    QRegularExpressionValidator m_percentValidator;  ///< Zoom percent input.
-    QComboBox *m_zoomBox; ///< The main zoom chooser/displayer widget.
     std::unique_ptr<core::RiskAnalysis> m_analysis; ///< Report container.
-    std::unordered_map<QTreeWidgetItem *, std::function<void()>>
-        m_reportActions; ///< Actions on elements of the report tree widget.
 };
 
 } // namespace gui
