@@ -771,7 +771,9 @@ class Bdd : private boost::noncopyable {
 
   /// Runs the Qualitative analysis
   /// with the representation of a PDAG as ROBDD.
-  void Analyze() noexcept;
+  ///
+  /// @param[in] graph  The optional PDAG with non-declarative substitutions.
+  void Analyze(const Pdag* graph = nullptr) noexcept;
 
   /// @returns Products generated by the analysis.
   ///
