@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 Olzhas Rakhimov
+ * Copyright (C) 2014-2017 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,70 +24,40 @@
 #include <exception>
 #include <string>
 
+#include <boost/current_function.hpp>
+#include <boost/exception/info.hpp>
+#include <boost/exception/exception.hpp>
+
+/// Convenience macro to throw SCRAM exceptions.
+/// This is similar to BOOST_THROW_EXCEPTION;
+/// however, it doesn't obfuscate
+/// the resultant exception type to conform to boost::exception.
+///
+/// @param[in] err  The error type deriving from boost::exception.
+#define SCRAM_THROW(err)                                                       \
+  throw err << ::boost::throw_function(BOOST_THROW_EXCEPTION_CURRENT_FUNCTION) \
+            << ::boost::throw_file(__FILE__) << ::boost::throw_line(__LINE__)
+
 namespace scram {
 
 /// The Error class is the base class
 /// for common exceptions specific to the SCRAM code.
-class Error : public std::exception {
+class Error : virtual public std::exception, virtual public boost::exception {
  public:
   /// Constructs a new error with a provided message.
   ///
   /// @param[in] msg  The message to be passed with this error.
-  explicit Error(std::string msg);
+  explicit Error(std::string msg) : msg_(std::move(msg)) {}
 
   Error(const Error&) = default;  ///< Explicit declaration.
 
   virtual ~Error() noexcept = default;
 
   /// @returns The formatted error message to be printed.
-  const char* what() const noexcept override;
-
-  /// @returns The core message describing the error.
-  const std::string& msg() const { return msg_; }
-
-  /// Sets the error messages.
-  ///
-  /// @param[in] msg  The error message.
-  void msg(std::string msg) {
-    msg_ = std::move(msg);
-    thrown_ = kPrefix_ + msg_;
-  }
+  const char* what() const noexcept final { return msg_.c_str(); }
 
  private:
-  static const char kPrefix_[];  ///< Prefix specific to SCRAM.
   std::string msg_;  ///< The error message.
-  std::string thrown_;  ///< The message to throw with the prefix.
-};
-
-/// For values that are not acceptable.
-/// For example, negative probability.
-struct ValueError : public Error {
-  using Error::Error;
-};
-
-/// For validating input parameters or user arguments.
-struct ValidationError : public Error {
-  using Error::Error;
-};
-
-/// For cases when events or practically anything is redefined.
-struct RedefinitionError : public ValidationError {
-  using ValidationError::ValidationError;
-};
-
-/// This error indicates that arguments must be unique.
-struct DuplicateArgumentError : public ValidationError {
-  using ValidationError::ValidationError;
-};
-
-/// The error for undefined elements in a model.
-struct UndefinedElement : public ValidationError {
-  using ValidationError::ValidationError;
-};
-
-/// Signals unacceptable cycles in invalid structures.
-struct CycleError : public ValidationError {
-  using ValidationError::ValidationError;
 };
 
 /// For input/output related errors.
@@ -95,9 +65,8 @@ struct IOError : public Error {
   using Error::Error;
 };
 
-/// This error class can be used
-/// to indicate unacceptable arguments.
-struct InvalidArgument : public Error {
+/// Dynamic library errors.
+struct DLError : public Error {
   using Error::Error;
 };
 
@@ -110,12 +79,83 @@ struct LogicError : public Error {
 
 /// This error can be used to indicate
 /// that call for a function or operation is not legal.
-/// For example, a derived class can make illegal
-/// the call of the virtual function of the base class.
 struct IllegalOperation : public Error {
   using Error::Error;
 };
 
+/// The error in analysis settings.
+struct SettingsError : public Error {
+  using Error::Error;
+};
+
+namespace mef {  // MEF specific errors.
+
+/// The MEF container element as namespace.
+using errinfo_container = boost::error_info<struct tag_contianer, std::string>;
+
+/// For validating input parameters or user arguments.
+struct ValidityError : public Error {
+  using Error::Error;
+};
+
+/// For cases when events or practically anything is redefined.
+struct RedefinitionError : public ValidityError {
+  using ValidityError::ValidityError;
+};
+
+/// This error indicates that arguments must be unique.
+struct DuplicateArgumentError : public ValidityError {
+  using ValidityError::ValidityError;
+};
+
+/// The error for undefined elements in a model.
+struct UndefinedElement : public ValidityError {
+  using ValidityError::ValidityError;
+};
+
+/// Signals unacceptable cycles in invalid structures.
+struct CycleError : public ValidityError {
+  using ValidityError::ValidityError;
+};
+
+/// Invalid domain for values or arguments.
+struct DomainError : public ValidityError {
+  using ValidityError::ValidityError;
+};
+
+}  // namespace mef
+
+namespace xml {
+
+/// The base for all XML related errors.
+struct Error : public scram::Error {
+  using scram::Error::Error;
+};
+
+/// XML parsing errors.
+struct ParseError : public Error {
+  using Error::Error;
+};
+
+/// XInclude resolution issues.
+struct XIncludeError : public Error {
+  using Error::Error;
+};
+
+/// XML document validity errors.
+struct ValidityError : public Error {
+  using Error::Error;
+};
+
+/// The XML attribute name.
+using errinfo_attribute =
+    boost::error_info<struct tag_xml_attribute, std::string>;
+
+/// The XML element name.
+using errinfo_element = boost::error_info<struct tag_xml_element, std::string>;
+
+}  // namespace xml
+
 }  // namespace scram
 
 #endif  // SCRAM_SRC_ERROR_H_
