@@ -24,8 +24,6 @@
 
 #include <string>
 
-#include "error.h"
-
 namespace scram {
 
 const char* const Logger::kLevelToString_[] = {"ERROR", "WARNING", "INFO",
@@ -39,14 +37,6 @@ Logger::~Logger() noexcept {
   std::fflush(stderr);  // Should be no-op for the unbuffered stderr.
 }
 
-void Logger::SetVerbosity(int level) {
-  if (level < 0 || level > kMaxVerbosity) {
-    throw InvalidArgument("Log verbosity must be between 0 and " +
-                          std::to_string(kMaxVerbosity));
-  }
-  report_level_ = static_cast<LogLevel>(level);
-}
-
 std::ostringstream& Logger::Get(LogLevel level) {
   os_ << Logger::kLevelToString_[level] << ": ";
   if (level > INFO)
