@@ -37,9 +37,6 @@ const char* core();
 /// @returns The version of the boost.
 const char* boost();
 
-/// @returns The version of the XML C++ wrapper.
-const char* libxmlpp();
-
 /// @returns The version of the XML C library.
 const char* libxml();
 
