@@ -35,6 +35,7 @@
 #include <boost/noncopyable.hpp>
 
 #include "bdd.h"
+#include "pdag.h"
 
 namespace scram {
 namespace core {
@@ -338,7 +339,11 @@ class Zbdd : private boost::noncopyable {
 
   /// Runs the analysis
   /// with the representation of a PDAG as ZBDD.
-  void Analyze() noexcept;
+  ///
+  /// @param[in] graph  The optional PDAG with non-declarative substitutions.
+  ///
+  /// @post Substitutions destroy all the modules.
+  void Analyze(const Pdag* graph = nullptr) noexcept;
 
   /// @returns Products generated by the analysis.
   const Zbdd& products() const { return *this; }
@@ -515,6 +520,12 @@ class Zbdd : private boost::noncopyable {
                     int current_order,
                     std::map<int, std::pair<bool, int>>* modules) noexcept;
 
+  /// Applies non-declarative substitutions at the end of analysis.
+  ///
+  /// @param[in] substitutions  The substitutions defined in PDAG.
+  void ApplySubstitutions(
+      const std::vector<Pdag::Substitution>& substitutions) noexcept;
+
   /// Clears all memoization tables.
   void ClearTables() noexcept {
     and_table_.clear();
