@@ -30,7 +30,17 @@ namespace test {
 TEST(InitializerTest, XMLFormatting) {
   EXPECT_THROW(Initializer({"./share/scram/input/xml_formatting_error.xml"},
                            core::Settings()),
-               ValidationError);
+               xml::ParseError);
+}
+
+// XML custom namespace errors.
+TEST(InitializerTest, XMLNameSpace) {
+  EXPECT_THROW(Initializer({"./share/scram/input/undefined_xmlns.xml"},
+                           core::Settings()),
+               xml::ParseError);
+  EXPECT_THROW(Initializer({"./share/scram/input/custom_xmlns.xml"},
+                           core::Settings()),
+               xml::ValidityError);
 }
 
 // Test the response for non-existent file.
@@ -48,7 +58,7 @@ TEST(InitializerTest, PassTheSameFileTwice) {
   std::string the_same_path = "./share/.."  // Path obfuscation.
                               "/share/scram/input/fta/correct_tree_input.xml";
   EXPECT_THROW(Initializer({input_correct, the_same_path}, core::Settings()),
-               ValidationError);
+               ValidityError);
 }
 
 // Test if the schema catches errors.
@@ -57,7 +67,7 @@ TEST(InitializerTest, PassTheSameFileTwice) {
 TEST(InitializerTest, FailSchemaValidation) {
   EXPECT_THROW(
       Initializer({"./share/scram/input/schema_fail.xml"}, core::Settings()),
-      ValidationError);
+      xml::ValidityError);
 }
 
 // Unsupported operations.
@@ -67,7 +77,8 @@ TEST(InitializerTest, UnsupportedFeature) {
                                     "../unsupported_gate.xml",
                                     "../unsupported_expression.xml"};
   for (const auto& input : incorrect_inputs) {
-    EXPECT_THROW(Initializer({dir + input}, core::Settings()), ValidationError)
+    EXPECT_THROW(Initializer({dir + input}, core::Settings()),
+                 xml::ValidityError)
         << " Filename:  " << input;
   }
 }
@@ -77,7 +88,8 @@ TEST(InitializerTest, EmptyAttributeElementText) {
   const char* incorrect_inputs[] = {"../empty_element.xml",
                                     "../empty_attribute.xml"};
   for (const auto& input : incorrect_inputs) {
-    EXPECT_THROW(Initializer({dir + input}, core::Settings()), ValidationError)
+    EXPECT_THROW(Initializer({dir + input}, core::Settings()),
+                 xml::ValidityError)
         << " Filename:  " << input;
   }
 }
@@ -144,7 +156,7 @@ TEST(InitializerTest, IncorrectEtaInputs) {
       "mixing_collect_instructions_link.xml",
       "mixing_collect_instructions_fork.xml"};
   for (const auto& input : incorrect_inputs) {
-    EXPECT_THROW(Initializer({dir + input}, core::Settings()), ValidationError)
+    EXPECT_THROW(Initializer({dir + input}, core::Settings()), ValidityError)
         << " Filename: " << input;
   }
 }
@@ -201,7 +213,8 @@ TEST(InitializerTest, IncorrectInclude) {
   std::string dir = "./share/scram/input/";
   const char* correct_inputs[] = {"xinclude_no_file.xml", "xinclude_cycle.xml"};
   for (const auto& input : correct_inputs) {
-    EXPECT_THROW(Initializer({dir + input}, core::Settings()), ValidationError)
+    EXPECT_THROW(Initializer({dir + input}, core::Settings()),
+                 xml::XIncludeError)
         << " Filename: " << input;
   }
 }
@@ -230,7 +243,6 @@ TEST(InitializerTest, IncorrectFtaInputs) {
   std::string dir = "./share/scram/input/fta/";
 
   const char* incorrect_inputs[] = {
-      "int_overflow.xml",
       "invalid_probability.xml",
       "private_at_model_scope.xml",
       "doubly_defined_gate.xml",
@@ -277,11 +289,16 @@ TEST(InitializerTest, IncorrectFtaInputs) {
       "repeated_ccf_members.xml"};
 
   for (const auto& input : incorrect_inputs) {
-    EXPECT_THROW(Initializer({dir + input}, core::Settings()), ValidationError)
+    EXPECT_THROW(Initializer({dir + input}, core::Settings()), ValidityError)
         << " Filename:  " << input;
   }
 }
 
+TEST(InitializerTest, IncorrectXMLOverflow) {
+  std::string input = "./share/scram/input/fta/int_overflow.xml";
+  EXPECT_THROW(Initializer({input}, core::Settings()), xml::ValidityError);
+}
+
 // Test failures triggered only in with probability analysis.
 TEST(InitializerTest, IncorrectProbabilityInputs) {
   std::string dir = "./share/scram/input/fta/";
@@ -290,7 +307,7 @@ TEST(InitializerTest, IncorrectProbabilityInputs) {
   core::Settings settings;
   settings.probability_analysis(true);
   for (const auto& input : incorrect_inputs) {
-    EXPECT_THROW(Initializer({dir + input}, settings), ValidationError)
+    EXPECT_THROW(Initializer({dir + input}, settings), ValidityError)
         << " Filename:  " << input;
   }
 }
@@ -308,13 +325,25 @@ TEST(InitializerTest, NonOrphanTopEvent) {
 TEST(InitializerTest, CorrectModelInputs) {
   std::string dir = "./share/scram/input/model/";
   const char* correct_inputs[] = {
+      "extern_library.xml",
+      "extern_function.xml",
+      "extern_expression.xml",
       "valid_alignment.xml",
       "valid_sum_alignment.xml",
-      "private_phases.xml"};
+      "private_phases.xml",
+      "substitution.xml",
+      "substitution_optional_source.xml",
+      "substitution_types.xml",
+      "substitution_declarative_target_is_another_source.xml",
+      "substitution_target_is_hypothesis.xml",
+      "substitution_declarative_ccf.xml",
+  };
 
+  core::Settings settings;
+  settings.approximation(core::Approximation::kRareEvent);
   for (const auto& input : correct_inputs) {
-    EXPECT_NO_THROW(Initializer({dir + input}, core::Settings()))
-        << " Filename: " << input;
+    EXPECT_NO_THROW(Initializer({dir + input}, settings, true)) << " Filename: "
+                                                                << input;
   }
 }
 
@@ -322,22 +351,92 @@ TEST(InitializerTest, IncorrectModelInputs) {
   std::string dir = "./share/scram/input/model/";
 
   const char* incorrect_inputs[] = {
+      "duplicate_extern_libraries.xml",
+      "duplicate_extern_functions.xml",
+      "undefined_extern_library.xml",
+      "undefined_symbol_extern_function.xml",
+      "invalid_num_param_extern_function.xml",
+      "undefined_extern_function.xml",
+      "invalid_num_args_extern_expression.xml",
+      "extern_library_invalid_path_format.xml",
       "duplicate_phases.xml",
       "invalid_phase_fraction.xml",
       "zero_phase_fraction.xml",
       "negative_phase_fraction.xml",
       "undefined_target_set_house_event.xml",
       "duplicate_alignment.xml",
-      "empty_alignment.xml",
       "excess_alignment.xml",
-      "incomplete_alignment.xml"};
+      "incomplete_alignment.xml",
+      "duplicate_substitution.xml",
+      "substitution_undefined_hypothesis_event.xml",
+      "substitution_undefined_source_event.xml",
+      "substitution_undefined_target_event.xml",
+      "substitution_duplicate_source_event.xml",
+      "substitution_duplicate_hypothesis_event.xml",
+      "substitution_nested_formula.xml",
+      "substitution_non_basic_event_formula.xml",
+      "substitution_type_mismatch.xml",
+      "substitution_no_effect.xml",
+      "substitution_nondeclarative_complex.xml",
+      "substitution_source_equal_target.xml",
+      "substitution_target_is_another_source.xml",
+      "substitution_target_is_another_hypothesis.xml",
+      "substitution_source_is_another_hypothesis.xml",
+      "substitution_source_false_target.xml",
+      "substitution_declarative_noncoherent.xml",
+      "substitution_nondeclarative_ccf_hypothesis.xml",
+      "substitution_nondeclarative_ccf_source.xml",
+      "substitution_nondeclarative_ccf_target.xml",
+  };
 
+  core::Settings settings;
+  settings.approximation(core::Approximation::kRareEvent);
   for (const auto& input : incorrect_inputs) {
-    EXPECT_THROW(Initializer({dir + input}, core::Settings()), ValidationError)
+    EXPECT_THROW(Initializer({dir + input}, settings, true), ValidityError)
         << " Filename:  " << input;
   }
 }
 
+TEST(InitializerTest, IncorrectModelEmptyInputs) {
+  std::string dir = "./share/scram/input/model/";
+  const char* incorrect_inputs[] = {"empty_extern_function.xml",
+                                    "empty_alignment.xml"};
+
+  for (const auto& input : incorrect_inputs) {
+    EXPECT_THROW(Initializer({dir + input}, core::Settings(), true),
+                 xml::ValidityError)
+        << " Filename:  " << input;
+  }
+}
+
+TEST(InitializerTest, ExternDLError) {
+  std::string input = "./share/scram/input/model/extern_library_ioerror.xml";
+  EXPECT_THROW(Initializer({input}, core::Settings(), true), DLError);
+}
+
+// Tests that external libraries are disabled by default.
+TEST(InitializerTest, DefaultExternDisable) {
+  std::string input = "./share/scram/input/model/extern_library.xml";
+  EXPECT_NO_THROW(Initializer({input}, core::Settings(), true));
+  EXPECT_THROW(Initializer({input}, core::Settings()), IllegalOperation);
+}
+
+// Non-declarative substitutions with approximations only.
+TEST(InitializerTest, NonDeclarativeSubstitutionsWithAppproximations) {
+  std::string input = "./share/scram/input/model/substitution_types.xml";
+  EXPECT_THROW(Initializer({input}, core::Settings()), ValidityError);
+
+  core::Settings settings;
+
+  settings.approximation(core::Approximation::kRareEvent);
+  EXPECT_NO_THROW(Initializer({input}, settings));
+  settings.approximation(core::Approximation::kMcub);
+  EXPECT_NO_THROW(Initializer({input}, settings));
+
+  settings.prime_implicants(true);
+  EXPECT_THROW(Initializer({input}, core::Settings()), ValidityError);
+}
+
 }  // namespace test
 }  // namespace mef
 }  // namespace scram
